@@ -44,6 +44,7 @@ define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
 define("nacos_config", default={}, type=dict, help="nacos配置")
 define("restful_handler", default=[], type=list, help="restful handler")
+define("rabbitmq_config", default={}, type=dict, help="rabbitmq配置")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -238,7 +239,8 @@ class WebServer:
                                                  weight=nacos_instance_weight,
                                                  metadata=options.nacos_config.get("instance_metadata"),
                                                  enable=nacos_instance_enable, healthy=nacos_instance_healthy,
-                                                 ephemeral=nacos_instance_ephemeral, group_name=nacos_instance_group_name)
+                                                 ephemeral=nacos_instance_ephemeral,
+                                                 group_name=nacos_instance_group_name)
                 logging.info(f'service={nacos_service_name} register success')
 
         except Exception as e:
